<?php
/**
 * @file
 * User Survey UI Form
 *
 */

/**
 * Menu callback for /node/%/manage-survey/[title]
 *
 */
function surveys_form(&$form_state, $node) {

  $form[$node->type] = array(
    '#type' => 'fieldset',
    '#title' => t('User Guide'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => variable_get('surveys_guide_'. $node->type, ''),
  );
  $form['questions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Questions for ' . $node->title),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
  );

  $categories = surveys_categories_get($node->type);
  
  // Get choices for this node
  $choices_result = db_query("SELECT cid, nid, qid, choice, enabled, weight, description FROM {surveys_choices} WHERE nid = %d AND enabled = 1 ORDER BY weight ASC", $node->nid);

  // Put choices in an array
  while ($choices_record = db_fetch_object($choices_result)) {
    $choices[$choices_record->qid][$choices_record->cid] = $choices_record->choice . ' (' . $choices_record->description . ')';
  }  
  
  //Get questions for this node 
  $result = db_query("SELECT sq.qid, sq.question, sq.description AS questdesc, sq.cid, sq.multiple, sq.enabled, sq.node_type, sc.category, sc.description AS catdesc, sm.mid, sm.enabled, sm.comment, sm.weight
                      FROM {surveys_questions} sq 
                      LEFT JOIN {surveys_manage} sm ON sq.qid = sm.qid 
                      LEFT JOIN {surveys_categories} sc ON sq.cid = sc.cid 
                      WHERE sq.node_type = '%s' AND uid = %d AND sm.enabled = 1 AND sq.qid IN (SELECT qid FROM {surveys_manage} WHERE nid = %d AND uid = %d)
                      ORDER BY sc.category, sm.weight, sq.question ASC", 
                      $node->type, $node->uid, $node->nid, $node->uid);  
    
  $questions = array();                                                  
  // Put choices on each question
  while ($record = db_fetch_object($result)) {
    $record->nid = $node->nid;
    $record->node_title = $node->title;
    $record->choices = $choices;
    $questions[] = _surveys_form($record);
  } 

  $category_group = surveys_categories_group($categories, $questions);
  
  $form['questions'] += $category_group;

  $form['submit'] = array( '#type' => 'submit', '#value' => t('Submit'), 
  
  );

  return $form;
}

/**
 * User Form
 *
 */
function _surveys_form($record) {
  //options
  for ($i = 1; $i < 11; $i++ ) {
    $options[$i*10] = $i; 
  }
  
  $form['qid'] = array(
    '#type' => 'hidden',
    '#value' => $record->qid,
  );
  $form['mid'] = array(
    '#type' => 'hidden',
    '#value' => $record->mid,
  ); 
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $record->nid,
  ); 
  $form['node_type'] = array(
    '#type' => 'hidden',
    '#value' => $record->node_type,
  );   
  $form['node_title'] = array(
    '#type' => 'hidden',
    '#value' => $record->node_title,
  );   
  $form['question_display'] = array(
    '#type' => 'markup',
    '#value' => '<h3>' . $record->question . '</h3><p>' . $record->questdesc . '</p>',
  );

  $form['question'] = array(
    '#type' => 'hidden',
    '#value' => $record->question,
  );
  $form['category'] = array(
    '#type' => 'hidden',
    '#return_value' => 1,
    '#default_value' => $record->cid,
    '#description' => $record->catdesc,
  );   
  if ($record->multiple && !empty($record->choices[$record->qid])) {
    $form['choices'] = array(
      '#type' => 'radios',
      '#title' => t('Choices'),
      '#return_value' => 1,
      '#options' => ($record->multiple) ? $record->choices[$record->qid] : '',
    );
  }
  else {
    $form['choices'] = array(
      '#type' => 'markup',
      '#title' => t('Choices'),
      '#return_value' => 1,
      '#value' => 'N/A'
    );
  }

  $form['rating'] = array(
    '#type' => 'select',
    '#title' => t('My Rating'),
    '#return_value' => 1,
    '#default_value' => 50,
    '#options' => $options,
    '#description' => t(''),
  );

  if (SURVEYS_FIVESTAR_ENABLE) {
    $form['rating']['#type'] = 'fivestar';
    $form['rating']['#stars'] = variable_get('surveys_fivestar_stars', 5);
  }

  if ($record->comment) {
    $form['comment'] = array(
      '#type' => 'textarea',
      '#title' => t('Comment'),
      '#return_value' => 1,
      '#default_value' => '',
      '#row' => 2,
      '#description' => t('Add you comments / suggestions.'),
    );
  }
  else {
    $form['comment'] = array(
      '#type' => 'markup',
      '#title' => t('Choices'),
      '#return_value' => 1,
      '#value' => 'Disabled.'
    );
  }      
  
  return $form;
}

/**
 * Form Submit
 *
 */
function surveys_form_submit($form, $form_state) {
  global $user;
  $votes = array();
  $form_values = $form_state['values'];
  foreach ($form_values['questions'] as $category) {
    foreach ($category as $myrating) {
      if ($myrating['rid']) {
        // Update an existing ratings
        // TODO
        $myrating['comment'] = check_plain($myrating['comment']);
        db_query("UPDATE {surveys_ratings} SET comment = '%s' WHERE rid = %d", $myrating['comment'], $myrating['rid']);
        drupal_set_message(t('The ratings and comments on "(' . $myrating['question'] . ')" has been updated.'));
      }
      elseif (!$myrating['rid']) {
        // Save ratings and comments
        $myrating['comment'] = check_plain($myrating['comment']);
        db_query("INSERT INTO {surveys_ratings} (nid, uid, qid, comment) VALUES (%d, %d, %d, '%s')", $myrating['nid'], $user->uid, $myrating['qid'], $myrating['comment']);
        // Use votingapi to save the ratings
        $votes[] = array('value' => $myrating['rating'], 'tag' => $myrating['question'], 'content_type' => 'node', 'content_id' => $myrating['nid']);
      }
      else {
        // Doesn't exist and don't use, so just ignore
      }
      $title = $myrating['node_title'];
    }
    
  }
  // votingapi_set_vote('rating', 'question', 'content_typ', 'content_id');
  votingapi_set_votes($votes);
  drupal_set_message(t('Your ratings and comments on "' . $title . '" has been saved.'));
}


/**
 * Implementation of theme_surveys_form()
 * - View in table format
 */
function theme_surveys_form($form) {
  $output = '';
  foreach (element_children($form['questions']) as $cat) {
    $rows = array();
    foreach (element_children($form['questions'][$cat]) as $key) {
      $row = array();
      // Strip labels
      $form['questions'][$cat][$key]['question_display']['#title'] = '';
      $form['questions'][$cat][$key]['choices']['#title'] = '';
      $form['questions'][$cat][$key]['rating']['#title'] = '';
      $form['questions'][$cat][$key]['comment']['#title'] = '';

      $row[] = drupal_render($form['questions'][$cat][$key]['question_display']);
      $row[] = drupal_render($form['questions'][$cat][$key]['choices']);
      $row[] = drupal_render($form['questions'][$cat][$key]['rating']);
      $row[] = drupal_render($form['questions'][$cat][$key]['comment']);
      $rows[] = $row;
    }
    $header = array('Questions', 'Choices', 'My Rating', 'Comments');
    // Header
    $form['questions'][$cat][$key]['#children'] = theme('table', $header, $rows);
  }
  $output .= drupal_render($form);
  return $output;
}






